@@ -16,18 +16,20 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
+ 
 import os
 import glob
 import socket
 import subprocess
 import hashlib
 import sys
-from func import new_key_req, uniq
+from .func import new_key_req, uniq
 from calculate.lib.utils import ip as ip
-from calculate.core.datavars import DataVarsCore
+from ..datavars import DataVarsCore
 from calculate.lib.utils.files import readFile
 from calculate.lib.utils.text import _u8
-import urllib2 as u2
+import urllib.request as u2
 
 if hasattr(u2, "ssl"):
     u2.ssl._create_default_https_context = u2.ssl._create_unverified_context
@@ -62,7 +64,7 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         if auto:
             c = 'n'
         else:
-            c = raw_input(_("Enter the certificate date manually? [y]/n: "))
+            c = input(_("Enter the certificate date manually? [y]/n: "))
         from M2Crypto import X509
 
         name = X509.X509_Name()
@@ -75,7 +77,7 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         lang = ob.Get('os_locale_locale')[:2]
 
         host_name = socket.getfqdn()
-        from create_cert import (passphrase_callback, generateRSAKey,
+        from .create_cert import (passphrase_callback, generateRSAKey,
                                  makePKey, CreateCertError, create_selfsigned_ca)
         # Generating public key
         rsa = generateRSAKey()
@@ -97,31 +99,31 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
             name['ST'] = 'Spb'  # (State Name);
             name['C'] = lang  # (Country);
         else:
-            print _('Do not use spaces or tabs.')
+            print(_('Do not use spaces or tabs.'))
             host_name = socket.getfqdn()
-            name['CN'] = raw_input(_('Hostname [%s] : ') % host_name)
+            name['CN'] = input(_('Hostname [%s] : ') % host_name)
             if name['CN'] in ['', None]:
                 name['CN'] = host_name
-            name['OU'] = raw_input(_('Organization unit: '))
+            name['OU'] = input(_('Organization unit: '))
             if not name['OU']:
                 name['OU'] = ''
             else:
                 name['OU'] = name['OU'].replace(' ', '_').replace('\t', '_')
-            name['O'] = raw_input(_('Organization name: '))
+            name['O'] = input(_('Organization name: '))
             if not name['O']:
                 name['O'] = ''
             else:
                 name['O'] = name['O'].replace(' ', '_').replace('\t', '_')
             network = _('Full network address (host:port)')
-            name['L'] = raw_input(network + ' [%s:%d]: ' % (host_name, port))
+            name['L'] = input(network + ' [%s:%d]: ' % (host_name, port))
             if name['L'] in ['', None]:
                 name['L'] = host_name + ':' + str(port)
-            name['ST'] = raw_input(_('City: '))
+            name['ST'] = input(_('City: '))
             if not name['ST']:
                 name['ST'] = ''
             else:
                 name['ST'] = name['ST'].replace(' ', '_').replace('\t', '_')
-            name['C'] = raw_input(_('Country (two letters only!) [%s]: ') % lang)
+            name['C'] = input(_('Country (two letters only!) [%s]: ') % lang)
             if not name['C']:
                 name['C'] = lang
 
@@ -138,16 +140,16 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         except IOError:
             print (_('error writing to (reading from) files in directory %s')
                    % cert_path)
-        print _("OK")
+        print(_("OK"))
 
     # use self root certificate as server certificate
     elif args.use_root_cert:
         if not os.path.exists(cert_path + '/root.crt'):
-            print _('root certificate not found (use cl-core with '
-                    'option --gen-root-cert)')
+            print(_('root certificate not found (use cl-core with '
+                    'option --gen-root-cert)'))
             return 1
 
-        print _('Using the root certificate as the server certificate')
+        print(_('Using the root certificate as the server certificate'))
         # use root certificate as server certificate
         ft = open(cert_path + '/root.crt', 'rb')
         fd = open(cert_path + '/server.crt', 'wb')
@@ -163,30 +165,30 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         ft.close()
         fd.close()
 
-        print _("OK")
+        print(_("OK"))
         return 0
 
     # send a certificate signing request to another server
     elif args.host:
         url = "https://%s:%d/?wsdl" % (args.host, port)
-        print url + '\n' + _("connecting...")
+        print(url + '\n' + _("connecting..."))
         import calculate.contrib
         from suds.client import Client
-        from client_class import HTTPSClientsCertTransport
-        from urllib2 import URLError
+        from .client_class import HTTPSClientsCertTransport
+        from urllib.error import URLError
 
         try:
             client = Client(url, transport=HTTPSClientsCertTransport(
                 None, None, None))
         except (KeyboardInterrupt, URLError):
-            print '\n' + _("Close. Connection Error.")
+            print('\n' + _("Close. Connection Error."))
             return 1
 
         serv_host_name = client.service.get_server_host_name()
 
         if os.path.exists(key) and os.path.exists(cert_path + '/server.csr'):
-            print _("the private key and request now exist")
-            ask = raw_input(_("Create a new private key and request?") +
+            print(_("the private key and request now exist"))
+            ask = input(_("Create a new private key and request?") +
                             " y/[n]: ")
             if ask.lower() in ['y', 'yes']:
                 new_key_req(key, cert_path, serv_host_name, port)
@@ -199,11 +201,11 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         res = client.service.post_server_request(request=data, ip=local_ip,
                                                  mac=mac)
         if int(res) < 0:
-            print _("This server is not enabled to sign certificates!")
+            print(_("This server is not enabled to sign certificates!"))
             return 1
         with open(cert_path + '/req_id', 'w') as fc:
             fc.write(res)
-        print _("Your request ID = %s") % _u8(res)
+        print(_("Your request ID = %s") % _u8(res))
         return 0
 
     # get a signed certificate from another server
@@ -215,44 +217,44 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         req_id = readFile(cert_path + '/req_id')
 
         url = "https://%s:%d/?wsdl" % (args.root_host, port)
-        print url + '\n' + _("connecting...")
+        print(url + '\n' + _("connecting..."))
 
         import calculate.contrib
         from suds.client import Client
-        from client_class import HTTPSClientsCertTransport
+        from .client_class import HTTPSClientsCertTransport
 
         try:
             client = Client(
                 url, transport=HTTPSClientsCertTransport(None, None, None))
         except KeyboardInterrupt:
-            print '\n' + _("Close. Connection Error.")
+            print('\n' + _("Close. Connection Error."))
             return 1
 
         request = readFile(cert_path + '/server.csr')
         md5 = hashlib.md5()
-        md5.update(request)
+        md5.update(request.encode("UTF-8"))
         md5sum = md5.hexdigest()
 
         result = client.service.get_server_cert(req_id, md5sum)
         cert = result[0][0]
         if cert == '1':
-            print _('The signature request was rejected!')
+            print(_('The signature request was rejected!'))
             return 1
         elif cert == '2':
-            print _("The signature request has not been examined yet.")
-            print _("Your request ID = %s") % req_id
+            print(_("The signature request has not been examined yet."))
+            print(_("Your request ID = %s") % req_id)
             return 1
         elif cert == '3':
-            print _('The signature request does not match earlier data.')
+            print(_('The signature request does not match earlier data.'))
             return 1
         elif cert == '4':
-            print _("The request was sent from another IP.")
+            print(_("The request was sent from another IP."))
             return 1
         with open(cert_path + '/server.crt', 'w') as fc:
             fc.write(cert)
         ca_root = result[0][1]
         os.unlink(cert_path + '/req_id')
-        print _('Certificate saved. Your certificate ID = %s') % req_id
+        print(_('Certificate saved. Your certificate ID = %s') % req_id)
         with open(cert_path + '/ca_root.crt', 'w') as fd:
             if ca_root:
                 fd.write(ca_root)
@@ -276,13 +278,13 @@ def create_path(data_path, certbase, rights, group_rights, local_data_path):
         try:
             os.makedirs(data_path + '/conf')
         except OSError:
-            print _("cannot create directory %s") % (data_path + '/conf')
+            print(_("cannot create directory %s") % (data_path + '/conf'))
 
     if not os.path.exists(local_data_path + '/conf'):
         try:
             os.makedirs(local_data_path + '/conf')
         except OSError:
-            print _("cannot create directory %s") % (local_data_path + '/conf')
+            print(_("cannot create directory %s") % (local_data_path + '/conf'))
 
     if not os.path.isfile(rights):
         rights_text = '# example of content:\n' + \
@@ -339,7 +341,7 @@ def find_cert_id(certificate, data_path, certbase):
     cert_path = data_path + '/client_certs/'
     for certId in cert_id:
         if os.path.isfile(cert_path + certId + '.crt'):
-            fp = open(cert_path + certId + '.crt', 'r')
+            fp = open(cert_path + certId + '.crt', 'rb')
             cert = fp.read()
             fp.close()
         else:
@@ -386,7 +388,7 @@ def del_cert(certbase, data_path, cert_id):
     try:
         os.unlink(data_path + '/client_certs/' + cert_id)
     except OSError:
-        print _("failed to delete the certificate!")
+        print(_("failed to delete the certificate!"))
 
 
 def add_right(cert_id, method, rights):
@@ -412,12 +414,12 @@ def add_right(cert_id, method, rights):
                         line = line.replace(' ' + word, '')
                 if not flag:
                     line += "%s " % cert_id
-                    print "id %s - add %s" % (cert_id, method)
+                    print("id %s - add %s" % (cert_id, method))
             ft.write(line + '\n')
     fd.close()
     if not find_perm_flag:
         ft.write('%s %s \n' % (method, str(cert_id)))
-        print "id %s - add %s" % (cert_id, method)
+        print("id %s - add %s" % (cert_id, method))
     ft.close()
 
     # copy all from temp file
@@ -452,12 +454,12 @@ def del_right(cert_id, method, rights):
                         line = line.replace(' ' + word, '')
                 if not flag:
                     line += "-%s " % cert_id
-                    print "id %s - remove %s" % (cert_id, method)
+                    print("id %s - remove %s" % (cert_id, method))
             ft.write(line + '\n')
     fd.close()
     if not find_perm_flag:
         ft.write('%s -%s \n' % (method, str(cert_id)))
-        print "id %s - remove %s" % (cert_id, method)
+        print("id %s - remove %s" % (cert_id, method))
     ft.close()
 
     # copy all from temp file
@@ -486,8 +488,8 @@ def change_rights_cert(cert_id, right_add, right_del,
                     int(i)
                     list_id.append(i)
             except ValueError:
-                print _('to change permissions, the certificate number must '
-                        'be integer')
+                print(_('to change permissions, the certificate number must '
+                        'be integer'))
                 return 1
 
     elif cert_id == 'all':
@@ -505,7 +507,7 @@ def change_rights_cert(cert_id, right_add, right_del,
 
         if right_add:
             if not os.path.exists(rights):
-                print _('file %s not found!') % rights
+                print(_('file %s not found!') % rights)
                 return 1
             ls_rig_add = right_add.split(',')
             for meth in ls_rig_add:
@@ -513,7 +515,7 @@ def change_rights_cert(cert_id, right_add, right_del,
 
         if right_del:
             if not os.path.exists(rights):
-                print _('file %s not found!') % rights
+                print(_('file %s not found!') % rights)
                 return 1
             ls_rig_del = right_del.split(',')
             for meth in ls_rig_del:
@@ -525,19 +527,19 @@ def view_cert_info(cert, cert_id, rights, group_rights):
     import OpenSSL
 
     certobj = OpenSSL.crypto.load_certificate(OpenSSL.SSL.FILETYPE_PEM, cert)
-    print certobj.get_extension(certobj.get_extension_count() - 1)
-    print _("Fingerprint = "), certobj.digest('SHA1')
-    print _("Serial number = "), certobj.get_serial_number()
+    print(certobj.get_extension(certobj.get_extension_count() - 1))
+    print(_("Fingerprint = "), certobj.digest('SHA1'))
+    print(_("Serial number = "), certobj.get_serial_number())
     issuer = certobj.get_issuer().get_components()
-    print '\n' + _("Issuer")
+    print('\n' + _("Issuer"))
     for i in issuer:
-        print "  %s : %s" % (i[0], i[1])
+        print("  %s : %s" % (i[0], i[1]))
     subject = certobj.get_subject().get_components()
-    print '\n' + _("Subject")
+    print('\n' + _("Subject"))
     for item in subject:
-        print "  %s : %s" % (item[0], item[1])
+        print("  %s : %s" % (item[0], item[1]))
 
-    print '\n' + _("Permissions: ")
+    print('\n' + _("Permissions: "))
 
     certobj = OpenSSL.crypto.load_certificate(OpenSSL.SSL.FILETYPE_PEM, cert)
     com = certobj.get_extension(certobj.get_extension_count() - 1).get_data()
@@ -590,7 +592,7 @@ def view_cert_info(cert, cert_id, rights, group_rights):
             sys.stdout.write(_(', except:') + '\n')
             sys.stdout.flush()
             for meth in del_list_rights:
-                print '  ' + meth
+                print('  ' + meth)
         return
 
     results += add_list_rights
@@ -601,10 +603,10 @@ def view_cert_info(cert, cert_id, rights, group_rights):
             results.remove(method)
 
     if not results:
-        print _("No methods available")
+        print(_("No methods available"))
     else:
         for meth in results:
-            print '  ' + meth
+            print('  ' + meth)
 
 
 # View, change rights, delete clients certificates on server
@@ -637,18 +639,18 @@ def view_cert(args, certbase, data_path, rights, group_rights):
                 if cert == 0:
                     count -= 1
                     continue
-                print _("Certificate ID = %s") % words[0]
+                print(_("Certificate ID = %s") % words[0])
                 if dump:
                     cert = find_id_cert(words[0], data_path)
                     if cert == 0:
                         count -= 1
                         continue
                     view_cert_info(cert, words[0], rights, group_rights)
-                    print "#############################################\n"
-        print _("Total: %d certificates.") % count
+                    print("#############################################\n")
+        print(_("Total: %d certificates.") % count)
 
         if remove:
-            answer = raw_input(
+            answer = input(
                 _("Are you sure? Delete all client certificates?") + ' y/[n]: ')
             if answer.lower() in ['y', 'yes']:
                 fc = open(certbase, "w")
@@ -657,25 +659,25 @@ def view_cert(args, certbase, data_path, rights, group_rights):
     try:
         cert_id = int(cert_id)
     except ValueError:
-        print _("certificate number not int and not 'all'")
+        print(_("certificate number not int and not 'all'"))
         return 1
 
     cert = find_id_cert(cert_id, data_path)
 
     if not cert:
-        print _("Certificate not found")
+        print(_("Certificate not found"))
         return 1
     if dump:
-        print cert
+        print(cert)
     else:
         view_cert_info(cert, cert_id, rights, group_rights)
 
     if remove:
-        answer = raw_input(
+        answer = input(
             _("Delete the client certificate with ID %d? y/[n]: ") % cert_id)
         if answer.lower() in ['y', 'yes']:
             del_cert(certbase, data_path, cert_id)
-            print _("Deleted")
+            print(_("Deleted"))
     return 0
 
 
@@ -689,29 +691,29 @@ def sing_req_by_server(id_client_req, cert_path, data_path, auto=False,
         try:
             int(id_client_req)
         except ValueError:
-            print _("The certificate number must be int")
+            print(_("The certificate number must be int"))
             return 1
         cl_req = data_path + '/client_certs/%s.csr' % id_client_req
         cl_cert = data_path + '/client_certs/%s.crt' % id_client_req
         if not os.path.exists(cl_req):
-            print _("Signature request %s not found") % cl_req
+            print(_("Signature request %s not found") % cl_req)
             return 1
 
         if os.path.exists(cl_cert):
-            print _("Certificate %s now exists") % cl_cert
+            print(_("Certificate %s now exists") % cl_cert)
             return 1
 
         if not auto:
             group_name = ""
             while not group_name.split():
-                group_name = "%s" % raw_input(
+                group_name = "%s" % input(
                     _("Enter the group of the new certificate "
                       "(group name or 'all'): "))
         config = data_path + '/client_certs/ssl-client.cfg'
         if os.path.exists(config):
             os.unlink(config)
 
-        from create_cert import (sign_client_certifacation_request,
+        from .create_cert import (sign_client_certifacation_request,
                 CreateCertError)
 
         try:
@@ -741,9 +743,9 @@ def sing_req_by_server(id_client_req, cert_path, data_path, auto=False,
         # stderr=subprocess.STDOUT, close_fds=True)
         # p.wait()
         if os.path.exists(cl_cert):
-            print _("Certificate %s is signed") % cl_cert
+            print(_("Certificate %s is signed") % cl_cert)
         else:
-            print _("Certificate %s has not been signed") % cl_cert
+            print(_("Certificate %s has not been signed") % cl_cert)
         return 0
 
 
@@ -753,24 +755,24 @@ def sing_req_by_root(args, cert_path, data_path):
     root_key = cert_path + '/root.key'
 
     if not os.path.exists(root_cert) or not os.path.exists(root_key):
-        print _("Root certificate or private key not found")
-        print _("see %s") % cert_path
+        print(_("Root certificate or private key not found"))
+        print(_("see %s") % cert_path)
         return 1
 
     if args.id_server_req:
         try:
             int(args.id_server_req)
         except ValueError:
-            print _("The certificate number must be int")
+            print(_("The certificate number must be int"))
             return 1
         sign_req = data_path + '/server_certs/%s.csr' % args.id_server_req
         sign_cert = data_path + '/server_certs/%s.crt' % args.id_server_req
         if not os.path.exists(sign_req):
-            print _("Signature request %s not found") % sign_req
+            print(_("Signature request %s not found") % sign_req)
             return 1
 
         if os.path.exists(sign_cert):
-            print _("Certificate %s now exists") % sign_cert
+            print(_("Certificate %s now exists") % sign_cert)
             return 1
 
             # config = cert_path + '/ssl-server-ca.cfg'
@@ -792,19 +794,19 @@ def sing_req_by_root(args, cert_path, data_path):
         cmd = ("openssl x509 -req -days 11000 -CA %s -CAkey %s -CAcreateserial "
                "-in %s -out %s") % (root_cert, root_key, sign_req, sign_cert)
 
-        print cmd
+        print(cmd)
         PIPE = subprocess.PIPE
         p = subprocess.Popen(cmd, shell=True, stdin=PIPE, stdout=PIPE,
                              stderr=subprocess.STDOUT, close_fds=True)
         p.wait()
-        print _("Certificate %s is signed") % sign_cert
+        print(_("Certificate %s is signed") % sign_cert)
         return 0
 
 
 # Detailed view server signed certificates
 def view_signed_cert_info(cert_id, serv_certbase, data_path, mid_path):
     cert_file = data_path + '/%s/%d.crt' % (mid_path, cert_id)
-    print cert_file
+    print(cert_file)
     import OpenSSL
 
     if os.path.exists(cert_file):
@@ -814,17 +816,17 @@ def view_signed_cert_info(cert_id, serv_certbase, data_path, mid_path):
         certobj = OpenSSL.crypto.load_certificate(
             OpenSSL.SSL.FILETYPE_PEM, cert)
         if mid_path == 'client_certs':
-            print certobj.get_extension(certobj.get_extension_count() - 1)
-        print _("Fingerprint = "), certobj.digest('SHA1')
-        print _("Serial number = "), certobj.get_serial_number()
+            print(certobj.get_extension(certobj.get_extension_count() - 1))
+        print(_("Fingerprint = "), certobj.digest('SHA1'))
+        print(_("Serial number = "), certobj.get_serial_number())
         issuer = certobj.get_issuer().get_components()
-        print '\n' + _("Issuer")
+        print('\n' + _("Issuer"))
         for i in issuer:
-            print "%s : %s" % (i[0], i[1])
+            print("%s : %s" % (i[0], i[1]))
         subject = certobj.get_subject().get_components()
-        print '\n' + _("Subject")
+        print('\n' + _("Subject"))
         for item in subject:
-            print "%s : %s" % (item[0], item[1])
+            print("%s : %s" % (item[0], item[1]))
 
         if not os.path.exists(serv_certbase):
             fc = open(serv_certbase, "w")
@@ -838,21 +840,21 @@ def view_signed_cert_info(cert_id, serv_certbase, data_path, mid_path):
                 words = line.split()
                 # if in line present certificate id
                 if words[0] == str(cert_id):
-                    print '\n' + _('request sent from:')
-                    print 'IP: %s' % words[4]
-                    print 'MAC: %s' % words[5]
-                    print _('date') + ' - %s %s' % (words[2], words[3])
+                    print('\n' + _('request sent from:'))
+                    print('IP: %s' % words[4])
+                    print('MAC: %s' % words[5])
+                    print(_('date') + ' - %s %s' % (words[2], words[3]))
                     break
 
     else:
-        print _("Certificate not found!")
+        print(_("Certificate not found!"))
 
-    print "\n###################################################\n"
+    print("\n###################################################\n")
 
     # Detailed view server request
     req_file = data_path + '/%s/%d.csr' % (mid_path, cert_id)
 
-    print req_file
+    print(req_file)
 
     if os.path.exists(req_file):
         fp = open(req_file, 'r')
@@ -862,9 +864,9 @@ def view_signed_cert_info(cert_id, serv_certbase, data_path, mid_path):
         reqobj = OpenSSL.crypto.load_certificate_request(
             OpenSSL.SSL.FILETYPE_PEM, request)
         subject = reqobj.get_subject().get_components()
-        print '\n' + _("Subject")
+        print('\n' + _("Subject"))
         for item in subject:
-            print " %s : %s" % (item[0], item[1])
+            print(" %s : %s" % (item[0], item[1]))
 
         if not os.path.exists(serv_certbase):
             fc = open(serv_certbase, "w")
@@ -878,13 +880,13 @@ def view_signed_cert_info(cert_id, serv_certbase, data_path, mid_path):
                 words = line.split()
                 # if in line present certificate id
                 if words[0] == str(cert_id):
-                    print '\n' + _('request sent from:')
-                    print 'IP: %s' % words[4]
-                    print 'MAC: %s' % words[5]
-                    print _('date') + ' - %s %s' % (words[2], words[3])
+                    print('\n' + _('request sent from:'))
+                    print('IP: %s' % words[4])
+                    print('MAC: %s' % words[5])
+                    print(_('date') + ' - %s %s' % (words[2], words[3]))
                     break
     else:
-        print _("Request for signature not found!")
+        print(_("Request for signature not found!"))
     return 0
 
 
@@ -908,22 +910,22 @@ def view_signed_cert(args, serv_certbase, data_path):
                 cert = '%s/server_certs/%s.crt' % (data_path, words[0])
                 req = '%s/server_certs/%s.csr' % (data_path, words[0])
                 if os.path.exists(cert):
-                    print 'Certificate \t', cert
+                    print('Certificate \t', cert)
                     count += 1
                 if os.path.exists(req):
                     if not os.path.exists(cert):
-                        print _('Request \t%s: not signed') % req
+                        print(_('Request \t%s: not signed') % req)
                     else:
-                        print _('Request \t%s') % req
+                        print(_('Request \t%s') % req)
                     count += 1
         if not count:
-            print _("Certificate or request not found!")
+            print(_("Certificate or request not found!"))
         return 0
 
     try:
         cert_id = int(cert_id)
     except ValueError:
-        print _("certificate (request) number not int and not 'all'")
+        print(_("certificate (request) number not int and not 'all'"))
         return 1
     view_signed_cert_info(cert_id, serv_certbase, data_path, 'server_certs')
     return 0
@@ -946,22 +948,22 @@ def view_client_request(args, client_certbase, data_path):
                 cert = '%s/client_certs/%s.crt' % (data_path, words[0])
                 req = '%s/client_certs/%s.csr' % (data_path, words[0])
                 if os.path.exists(cert):
-                    print _('Certificate \t'), cert
+                    print(_('Certificate \t'), cert)
                     count += 1
                 if os.path.exists(req):
                     if not os.path.exists(cert):
-                        print _('Request \t%s: not signed') % req
+                        print(_('Request \t%s: not signed') % req)
                     else:
-                        print _('Request \t%s') % req
+                        print(_('Request \t%s') % req)
                     count += 1
         if not count:
-            print _("Certificate or request not found!")
+            print(_("Certificate or request not found!"))
         return 0
 
     try:
         req_id = int(req_id)
     except ValueError:
-        print _("certificate (request) number not int and not 'all'")
+        print(_("certificate (request) number not int and not 'all'"))
         return 1
     view_signed_cert_info(req_id, client_certbase, data_path, 'client_certs')
     return 0
@@ -981,27 +983,27 @@ def del_request(id_del_serv_req, id_del_client_req, serv_certbase,
     try:
         int(id_del_req)
     except ValueError:
-        print _("The ID must be int.")
+        print(_("The ID must be int."))
         return 1
 
     request = os.path.join(data_path, sub_path, '%s.csr' % id_del_req)
     cert = os.path.join(data_path, sub_path, '%s.crt' % id_del_req)
 
     # chect exists request and certificate files 
-    print request
+    print(request)
     if not os.path.exists(request) and not os.path.exists(cert):
-        print _("Request or certificate with ID = %s not found!") % id_del_req
+        print(_("Request or certificate with ID = %s not found!") % id_del_req)
         return 1
 
     if not os.path.exists(request):
-        print _("request %s not found!") % request
+        print(_("request %s not found!") % request)
 
     if os.path.exists(cert):
-        print _("Request duly signed")
-        ask = raw_input(
+        print(_("Request duly signed"))
+        ask = input(
             _("Delete the certificate and the signature request? y/[n]: "))
         if not ask.lower() in ['y', 'yes']:
-            print _("Not deleted")
+            print(_("Not deleted"))
             return 0
 
     # create temp file
@@ -1031,12 +1033,12 @@ def del_request(id_del_serv_req, id_del_client_req, serv_certbase,
     try:
         if os.path.exists(request):
             os.unlink(request)
-            print _("signature request deleted")
+            print(_("signature request deleted"))
         if os.path.exists(cert):
             os.unlink(cert)
-            print _("certificate deleted")
+            print(_("certificate deleted"))
     except OSError:
-        print _("failed to delete the file!")
+        print(_("failed to delete the file!"))
 
 
 def revoke_signed_cert(revoke_cert_id, data_path, cert_path):
@@ -1051,20 +1053,20 @@ def revoke_signed_cert(revoke_cert_id, data_path, cert_path):
 
         if os.path.exists(CRL):
             os.unlink(CRL)
-            print _("CRL deleted")
+            print(_("CRL deleted"))
             return 0
-        print _("CRL does not exist")
+        print(_("CRL does not exist"))
         return 0
 
     try:
         int(revoke_cert_id)
     except ValueError:
-        print _("The ID of a certificate to be revoked must be integer!")
+        print(_("The ID of a certificate to be revoked must be integer!"))
         return 1
 
     cert_file = data_path + "/server_certs/%s.crt" % revoke_cert_id
     if not os.path.exists(cert_file):
-        print _("Certificate %s not found") % cert_file
+        print(_("Certificate %s not found") % cert_file)
         return 1
 
     if not os.path.exists(CRL_db_dir):
@@ -1108,7 +1110,7 @@ def revoke_signed_cert(revoke_cert_id, data_path, cert_path):
     cmd_create_crl = "openssl ca -gencrl -config %s -out %s" % (conf_file, CRL)
     os.system(cmd_create_crl)
 
-    print
+    print()
     cmd_show_crl = "openssl crl -text -noout -in %s" % CRL
     os.system(cmd_show_crl)
 
@@ -1116,7 +1118,7 @@ def revoke_signed_cert(revoke_cert_id, data_path, cert_path):
 #################################################################
 def parse(full=False):
     import argparse
-    from methods_func import RawAndDefaultsHelpFormatter
+    from .methods_func import RawAndDefaultsHelpFormatter
 
     parser = argparse.ArgumentParser(
         add_help=False, formatter_class=RawAndDefaultsHelpFormatter)
