@@ -14,14 +14,15 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
 import os
 import glob
 import sys
 import time
 import datetime
 import pickle
-from calculate.core.datavars import DataVarsCore
-from calculate.core.server.core_interfaces import CoreServiceInterface
+from ..datavars import DataVarsCore
+from .core_interfaces import CoreServiceInterface
 from calculate.lib.cl_lang import setLocalTranslate
 
 _ = lambda x: x
@@ -62,9 +63,9 @@ class CoreWsdl(CoreServiceInterface):
 
             cls.delete_pid(cls, sid, pid)
         except IOError as e:
-            print 'Except IOError', str(e)
+            print('Except IOError', str(e))
         except Exception:
-            print _("PID %d watcher error") % pid
+            print(_("PID %d watcher error") % pid)
             try:
                 cls.delete_pid(cls, sid, pid)
             except Exception:
@@ -95,16 +96,16 @@ def monitor(certbase, sid_file):
         period = float(ob.Get('cl_core_monitor_period'))
         sid_live = float(ob.Get('cl_core_sid_live'))
     except Exception:
-        print _("Variable cl_core_monitor_period or cl_core_sid_live not "
-                "found")
+        print(_("Variable cl_core_monitor_period or cl_core_sid_live not "
+                "found"))
         raise
     # Check lifetime. if necessary, remove
     while True:
         # check session
         try:
             sid_file_t = sid_file + '_temp'
-            fd = open(sid_file, 'r')
-            ft = open(sid_file_t, 'w')
+            fd = open(sid_file, 'rb')
+            ft = open(sid_file_t, 'wb')
             while 1:
                 try:
                     # read all on one record
@@ -145,9 +146,9 @@ def sid_monitor(sid_fn, sids_dn, cls):
             sids = []
             # create, if file not exists
             if not os.path.exists(sid_fn):
-                temp = open(sid_fn, 'w')
+                temp = open(sid_fn, 'wb')
                 temp.close()
-            fd = open(sid_fn, 'r')
+            fd = open(sid_fn, 'rb')
             while 1:
                 try:
                     # read all on one record
@@ -158,7 +159,7 @@ def sid_monitor(sid_fn, sids_dn, cls):
                 sids.append(list_sid[0])
             fd.close()
         except (IOError, OSError):
-            print _("Error reading SID files")
+            print(_("Error reading SID files"))
             return
 
         try:
@@ -168,7 +169,7 @@ def sid_monitor(sid_fn, sids_dn, cls):
                 sid_path = sids_dn + "/%d.sid" % filename
                 with cls.sid_locker:
                     if os.path.isfile(sid_path):
-                        with open(sid_path) as fd:
+                        with open(sid_path, "rb") as fd:
                             # read information about session
                             sid_inf = pickle.load(fd)
                             # if number of missed inspections more 3
@@ -179,7 +180,7 @@ def sid_monitor(sid_fn, sids_dn, cls):
                         if os.path.isfile(sid_path):
                             # add to digit missed inspections
                             # client constantly nulls this value!
-                            ft = open(sid_path, 'w')
+                            ft = open(sid_path, 'wb')
                             if sid_inf[1] < 4:
                                 sid_inf[1] += 1
                             pickle.dump(sid_inf, ft)
